filter.c: Handle filter errors gracefully.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 2eb4e3db8315ba1baedabbbfcefff369a6f3f058..a73ada5d06039b0d9c175c3266b581dd0a79d689 100644 (file)
--- a/write.h
+++ b/write.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -101,10 +101,8 @@ struct writer_node_group {
        struct writer_node *writer_nodes;
        /** the maximum of the chunk_bytes values of the writer nodes in this group */
        size_t max_chunk_bytes;
-       /** non-zero if end of file was encountered by the feeding task */
-       int *input_eof;
-       /** non-zero if end of file was encountered */
-       int eof;
+       /** Non-zero if an error or end of file was encountered by the feeding task. */
+       int *input_error;
        /** current output buffer */
        char *buf;
        /** number of bytes loaded in the output buffer */